@@ -1,6 +1,4 @@
 
-context("test-df-spatial-raster")
-
 test_that("Raster* objects are converted properly by df_spatial", {
   skip_if_not_installed("raster")
 
@@ -18,12 +16,12 @@ test_that("Raster* objects are converted properly by df_spatial", {
 
   skip_if_not_installed("vdiffr")
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger_extra(
     "df_spatial(), raster",
     ggplot(df_spatial(longlake_depth_raster)) + ggplot2::geom_raster(aes(x, y, fill = band1))
   )
 
-  vdiffr::expect_doppelganger(
+  expect_doppelganger_extra(
     "df_spatial(), nband raster",
     ggplot(df_spatial(longlake_osm)) + ggplot2::geom_raster(aes(x, y, fill = band1))
   )
@@ -65,3 +63,26 @@ test_that("na.rm works on df_spatial.Raster()", {
   expect_false(any(is.na(df_finite$band2)))
   expect_false(any(is.na(df_finite$band3)))
 })
+
+test_that("Factor Raster* objects are properly converted", {
+  # Test factor RasterLayer
+  r_num <- raster::raster(nrows = 3, ncols = 3, crs = raster::crs(4326), xmn = 0, xmx = 3,
+                          ymn = 0, ymx = 3, vals = c(1,2,3,3,1,2,2,3,1))
+  r_fac <- raster::as.factor(r_num)
+  levels(r_fac) <-
+      data.frame(ID = 1:3, landcover = c("grassland", "savannah", "forest"))
+  expect_true(inherits(df_spatial(r_num)[["band1"]], "numeric"))
+  expect_true(inherits(df_spatial(r_fac)[["band1"]], "factor"))
+  expect_identical(levels(df_spatial(r_fac)[["band1"]]),
+                   c("grassland", "savannah", "forest"))
+
+  # Test RasterStack with mixed factor and numeric layers
+  s <- raster::stack(r_fac, r_num, r_fac)
+  expect_identical(unname(sapply(df_spatial(s)[-1:-2], class)),
+                   c("factor", "numeric", "factor"))
+
+  # Test factor RasterBrick
+  b <- raster::brick(r_fac, r_fac, r_fac)
+  expect_identical(unname(sapply(df_spatial(b)[-1:-2], class)),
+                   c("factor", "factor", "factor"))
+})
