@@ -63,7 +63,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     expect_doppelganger_extra(
       "layer_spatial.Raster() aes(band1)",
       ggplot() +
-        layer_spatial(longlake_osm, aes(alpha = stat(band1), fill = NULL)) +
+        layer_spatial(longlake_osm, aes(alpha = after_stat(band1), fill = NULL)) +
         layer_spatial(longlake_depthdf)
     )
 
